from django.contrib import sitemaps
from .models import SitemappedModel


class Sitemap(sitemaps.Sitemap):

    def __init__(self):
        self.queryset.model.sitemap_entry = SitemappedModel.sitemap_entry

    def items(self):
        return self.queryset.filter()

    def changefreq(self, obj):
        try:
            setting = obj.sitemap_entry.get_changefreq_display()
        except:
            setting = self.default_changefreq
        return setting

    def priority(self, obj):
        try:
            setting = obj.sitemap_entry.priority
        except:
            setting = self.default_priority
        return setting



from django.conf.urls import url
from django.contrib.sitemaps.views import sitemap
from django.http import HttpResponse
from django.views.generic import base

from sitemapper.tests.test_sitemap import DummySitemap


class TestView(base.View):
    def get(self, request, *args, **kwargs):
        return HttpResponse('Hello Test World!')


sitemaps = {
    'tests': DummySitemap,
    }


urlpatterns = [

    url(r'^(?P<slug>[-_\w]+)/$',
        TestView.as_view(),
        name='sitemapper.tests.views.detail'
        ),

    url(r'^sitemap\.xml', sitemap, {'sitemaps': sitemaps},
        name='django.contrib.sitemaps.views.sitemap'),

    ]
